"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.camelCase = void 0;
const capitalize_1 = require("@zodash/capitalize");
const camelCasePatten = '([A-Z]?[a-z]+)';
const lowerCasePattern = '([a-zA-Z]+)';
const pattern = new RegExp(`${camelCasePatten}|${lowerCasePattern}`, 'g');
function words(value) {
    return value.match(pattern);
}
/**
 * Converts a string value into [camel case](https://en.wikipedia.org/wiki/Camel_case).
 * @param value The string to convert.
 * @returns The camel-cased string.
 * @example ```ts
 camelCase('foo-bar-baz')
 // => 'fooBarBaz'
 ```
 */
function camelCase(value) {
    return words(value).reduce((result, word, index) => {
        const lower = word.toLowerCase();
        return result + (index ? capitalize_1.capitalize(lower) : lower);
    }, '');
}
exports.camelCase = camelCase;
//# sourceMappingURL=camelCase.js.map